@@ -16,6 +16,14 @@ _tfreq = {
     "year": ["AS", "A"],
 }
 
+_bfreq = {
+    "fx": None,
+    "day": ["D", "D", 12],
+    "week": ["7D", "7D", 42],
+    "mon": ["MS", "M", 12],
+    "sem": ["QS-DEC", "Q-FEB", 12],
+    "year": ["AS", "A", 12],
+}
 _bounds = {
     "fx": {
         "start": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12],
@@ -48,9 +56,9 @@ _fmt = {
 
 _split = {
     "fx": False,
-    "day": "5AS",
-    "week": "10AS",
-    "mon": "10AS",
-    "sem": "10AS",
-    "year": "20AS",
+    "day": "5A",
+    "week": "10A",
+    "mon": "10A",
+    "sem": "10A",
+    "year": "20A",
 }
